==> hermes-2.4.10.3.tar.gz: hermes-2.4.10.3/app/jobs/update_score_from_offer_job.rb <==
class UpdateScoreFromOfferJob < ActiveJob::Base
  queue_as :x_hermes_score_offers

  def perform(offer_id)
    Resque::Job.destroy('x_hermes_score_offers', UpdateScoreFromOfferJob, offer_id)
    i=0
    eligible_applicant_ids = []
    offer = Hermes::HousingOffer.only(:id, :effort_rate, :lessor_id, :typology, :eligibility_query).find_by(id: offer_id)
    unless offer.formated_eligibility.blank?  
      eligible_applicant_ids = Hermes::HousingRequest.where(is_active: true, in_progress: true, **offer.formated_eligibility).pluck(:main_applicant_id).map(&:to_s)
    end
    total = eligible_applicant_ids.length
    return unless eligible_applicant_ids.present?

    UpdateOfferEligibleNbJob.perform_later(offer_id.to_s)

    found_or_created_scores = []
    eligible_applicant_ids.each do |applicant_id|
      applicant = Hermes::Applicant.only(:id).find_by(id: applicant_id)

      next unless offer && applicant

      score = Hermes::Score.find_or_create_by(housing_offer_id: offer_id, applicant_id: applicant_id, is_active: true) do
        # Enter here only if score was created
        # Temporary_disabled_devops_7390
        # channels = HERMES_CONFIG["housing_offer_notifications"] ? ['email'] : []
        # offer.notify(key: NOTIFICATION_KEYS[:housing_offer][:new_eligible_offer], channels: channels)
      end
      score.save

      Rails.logger.debug "calc score for offer [#{i}/#{total}] #{offer_id} applicant : #{applicant_id} score : #{score.id}"
      found_or_created_scores << applicant_id.to_s
    end

    applicant_filter = { :$nin => found_or_created_scores }

    other_scores = Hermes::Score.where(housing_offer_id: offer_id, applicant_id: applicant_filter)

    other_scores.set(is_active: false, updated_at: DateTime.current)

    Rails.logger.debug "#{other_scores.count} scores have been set to inactive for housing_offer : #{offer_id}"
  end
end

==> hermes-2.4.10.4.tar.gz: hermes-2.4.10.4/app/jobs/update_score_from_offer_job.rb <==
class UpdateScoreFromOfferJob < ActiveJob::Base
  queue_as :x_hermes_score_offers

  def perform(offer_id)
    Resque::Job.destroy('x_hermes_score_offers', UpdateScoreFromOfferJob, offer_id)
    i=0
    eligible_applicant_ids = []
    offer = Hermes::HousingOffer.only(:id, :effort_rate, :lessor_id, :typology, :eligibility_query).find_by(id: offer_id)
    unless offer.formated_eligibility.blank?  
      eligible_applicant_ids = Hermes::HousingRequest.where(is_active: true, in_progress: true, **offer.formated_eligibility).pluck(:main_applicant_id).map(&:to_s)
    end
    total = eligible_applicant_ids.length
    return unless eligible_applicant_ids.present?

    UpdateOfferEligibleNbJob.perform_later(offer_id.to_s)

    found_or_created_scores = []
    eligible_applicant_ids.each do |applicant_id|
      applicant = Hermes::Applicant.only(:id).find_by(id: applicant_id)

      next unless offer && applicant

      score = Hermes::Score.find_or_create_by(housing_offer_id: offer_id, applicant_id: applicant_id, is_active: true) do
        # Enter here only if score was created
        # Temporary_disabled_devops_7390
        # channels = HERMES_CONFIG["housing_offer_notifications"] ? ['email'] : []
        # offer.notify(key: NOTIFICATION_KEYS[:housing_offer][:new_eligible_offer], channels: channels)
      end
      score.save

      Rails.logger.debug "calc score for offer [#{i}/#{total}] #{offer_id} applicant : #{applicant_id} score : #{score.id}"
      found_or_created_scores << score.id.to_s
    end

    other_scores = Hermes::Score.where(housing_offer_id: offer_id, id: { :$nin => found_or_created_scores })

    other_scores.set(is_active: false, updated_at: DateTime.current)

    Rails.logger.debug "#{other_scores.count} scores have been set to inactive for housing_offer : #{offer_id}"
  end
end
